/*
 * grunt-cli
 * http://gruntjs.com/
 *
 * Copyright (c) 2012 Tyler Kellen, contributors
 * Licensed under the MIT license.
 * https://github.com/gruntjs/grunt-init/blob/master/LICENSE-MIT
 */

// format Ctrl+shift+F

'use strict';

module.exports = function (grunt) {

    // Project configuration.
    grunt.initConfig({
        pkg: grunt.file.readJSON('package.json'),
        src: '',
        dest: '',
        imagemin: {
            dist: {
                options: {
                    optimizationLevel: 3
                },
                files: [{
                    expand: true,
                    cwd: 'source/images/', //要压缩的文件夹
                    src: ['**/*.{png,jpg,gif,jpeg}'], //压缩文件类型
                    dest: 'test/images/'//存放路径
                }, {
                    expand: true,
                    cwd: '',
                    src: [],
                    dest: ''
                }]
            }
        },
        clean: {
            //清理一个空目录
            foo: {
                src: ['images/**/*'],
                filter: function (filepath) {
                    return (grunt.file.isDir(filepath) && require('fs').readdirSync(filepath).length === 0);
                },
            }
        },
        stylus: {
            //任务将src目录下的所有.styl文件编译成.css文件
            options: {
                //指定要扫描的目录（针对@import内的路径）
                paths: ['css'],
                //指定将图片路径转成base64数据的函数（比如配置urlfunc:"embedurl"，扫描embedurl(test.png)）
                urlfunc: 'img',
                import: [//  @import 'foo', 'bar/moo', 每一个.styl文件
                    'css']
            },
            main: {
                files: [{
                    expand: true,
                    cwd: 'css',
                    src: '*.styl',
                    dest: 'src',
                    ext: '.css'
                }]
            }
        },
        yuidoc: {
            //yuidoc文档生成插件
            compile: {
                name: '<%= pkg.name %>',
                description: '<%= pkg.description %>',
                version: '<%= pkg.version %>',
                url: '<%= pkg.homepage %>',
                options: {
                    paths: 'path/to/source/code/', //js源码位置
                    themedir: 'path/to/custom/theme/', //文档模板位置
                    outdir: 'where/to/save/docs/'	//文档输出位置
                }
            }
        },
        karma: {
            unit: {
                configFile: 'karma.conf.js'	//会寻找karma.conf.j配置文件
            }
        },
        watch: {
            options: {
                livereload: true,
            },
            css: {
                files: ['public/scss/*.scss'],
                tasks: ['compass'],
            },
        },
        jshint: {
            foo:{
                files:['src/*.js', 'src/**/*.js']
            }
        },
        concat: {
            //定义一个字符串插入每个文件之间用于连接输出
            option: {
                separator: ';'
            },
            dist: {
                src: ['src/*.js', 'src/**/*.js'],
                dest: 'js/plugin/Prometheus-min.js'
            }
        },
        uglify: {

            options: {
                banner: '/*! <%= pkg.name %> <%= grunt.template.today("yyyy-mm-dd") %> */\n'
            },
            builda: {
                /*
                 * 任务一：压缩a.js，不混淆变量名，保留注释，添加banner和footer
                 * @mangle 不混淆变量名
                 * @perserveComments 不删除注释，还可以为 false（删除全部注释），some（保留@preserve @license @cc_on等注释）
                 * @footer 添加footer
                 */
                options: {
                    mangle: false,
                    preserveComments: 'all',
                    footer: '\n/*! <%= pkg.name %> 最后修改于： <%= grunt.template.today("yyyy-mm-dd") %> */',
                },
                files: {
                    'js/plugin/Prometheus.min.js': ['src/*.js', 'src/**/*.js']
                },
            },
            buildb: {
                /*
                 * 任务二：压缩b.js，输出压缩信息
                 * @report 输出压缩率，可选的值有 false(不输出信息)，gzip
                 */
                options: {
                    report: "min"//输出压缩率，可选的值有 false(不输出信息)，gzip
                },
                files: {
                    'js/plugin/Prometheus-min.js': ['src/*.js', 'src/**/*.js']
                }
            },
            buildall: {
                /*
                 * 任务三：按原文件结构压缩js文件夹内所有JS文件
                 * @cwd js目录下
                 * @src 所有js文件
                 * @dest 输出到此目录下
                 */
                files: [{
                    expand: true,
                    cwd: 'source/js/', //js目录下
                    src: '**/*.js', //所有js文件
                    dest: 'test/js/'//输出到此目录下
                }]
            },
            release: {
                /*
                 * 任务四：合并压缩a.js和b.js
                 */
                files: {
                    'Prometheus/dist/Prometheus-min.js': ['src/*.js', 'src/**/*.js']
                }
            }
        }
    });
    /*
     * 配置插件
     */
    //配置js 语法检查
    grunt.loadNpmTasks('grunt-contrib-jshint');
    //配置图片压缩插件
    // grunt.loadNpmTasks('grunt-contrib-imagemin');

    //采用UglifyJS压缩js
    grunt.loadNpmTasks('grunt-contrib-uglify');

    //js合并
    // grunt.loadNpmTasks('grunt-contrib-concat');
    // 文档压缩
    // grunt.loadNpmTasks('grunt-contrib-yuidoc');

    //执行清除
    grunt.registerTask('clean', ['clean']);

    /*
     * 测试其他方法
     * "npm test" runs these tasks
     * 单事件
     * grunt.registerTask('jshint', ['jshint']);
     *
     */

    // Default task.
    // grunt.registerTask('default', 'uglify');执行该插件下的所有规则，也可uglify:release，uglify:buildall，其中之一
    grunt.registerTask('default', ['uglify:release']);

};
